@@ -1,8 +1,9 @@
 from typing import List, Optional
 
-from pydantic import BaseModel
+from lago_python_client.base_model import BaseModel
 
-from .charge import Charges, ChargesResponse
+from .charge import Charges, ChargesResponse, ChargesOverrides
+from .minimum_commitment import MinimumCommitment, MinimumCommitmentResponse, MinimumCommitmentOverrides
 from .tax import Taxes, TaxesResponse
 from ..base_model import BaseResponseModel
 
@@ -19,6 +20,7 @@ class Plan(BaseModel):
     pay_in_advance: Optional[bool]
     bill_charges_monthly: Optional[bool]
     charges: Optional[Charges]
+    minimum_commitment: Optional[MinimumCommitment]
     tax_codes: Optional[List[str]]
 
 
@@ -36,6 +38,18 @@ class PlanResponse(BaseResponseModel):
     pay_in_advance: Optional[bool]
     bill_charges_monthly: Optional[bool]
     charges: Optional[ChargesResponse]
+    minimum_commitment: Optional[MinimumCommitmentResponse]
     active_subscriptions_count: int
     draft_invoices_count: int
     taxes: Optional[TaxesResponse]
+
+class PlanOverrides(BaseModel):
+    name: Optional[str]
+    invoice_display_name: Optional[str]
+    description: Optional[str]
+    amount_cents: Optional[int]
+    amount_currency: Optional[str]
+    trial_period: Optional[float]
+    charges: Optional[ChargesOverrides]
+    minimum_commitment: Optional[MinimumCommitmentOverrides]
+    tax_codes: Optional[List[str]]
