@@ -10,7 +10,7 @@ class Subscription(BaseModel):
     external_customer_id: Optional[str]
     name: Optional[str]
     external_id: Optional[str]
-    subscription_date: Optional[str]
+    subscription_at: Optional[str]
     billing_time: Optional[str]
     ending_at: Optional[str]
     plan_overrides: Optional[PlanOverrides]
@@ -30,7 +30,7 @@ class SubscriptionResponse(BaseResponseModel):
     billing_time: Optional[str]
     terminated_at: Optional[str]
     ending_at: Optional[str]
-    subscription_date: Optional[str]
+    subscription_at: Optional[str]
     previous_plan_code: Optional[str]
     next_plan_code: Optional[str]
     downgrade_plan_date: Optional[str]
