@@ -1,6 +1,6 @@
 from typing import Optional
 
-from pydantic import BaseModel
+from lago_python_client.base_model import BaseModel
 
 from ..base_model import BaseResponseModel
 
@@ -9,12 +9,14 @@ class WalletTransaction(BaseModel):
     wallet_id: Optional[str]
     paid_credits: Optional[str]
     granted_credits: Optional[str]
+    voided_credits: Optional[str]
 
 
 class WalletTransactionResponse(BaseResponseModel):
     lago_id: str
     lago_wallet_id: str
     status: str
+    transaction_status: str
     transaction_type: str
     amount: str
     credit_amount: str
